==> poi-tl-ext-0.4.10-poi5-sources.jar: org/ddr/poi/html/tag/MathRenderer.java <==
/*
 * Copyright 2016 - 2021 Draco, https://github.com/draco1023
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ddr.poi.html.tag;

import org.ddr.poi.html.ElementRenderer;
import org.ddr.poi.html.HtmlConstants;
import org.ddr.poi.html.HtmlRenderContext;
import org.ddr.poi.math.MathMLUtils;
import org.jsoup.nodes.Element;

/**
 * math标签渲染器
 *
 * @author Draco
 * @since 2021-02-18
 */
public class MathRenderer implements ElementRenderer {
    private static final String[] TAGS = {HtmlConstants.TAG_MATH};

    /**
     * 开始渲染
     *
     * @param element HTML元素
     * @param context 渲染上下文
     * @return 是否继续渲染子元素
     */
    @Override
    public boolean renderStart(Element element, HtmlRenderContext context) {
        String math = element.outerHtml();

        MathMLUtils.renderTo(context.getClosestParagraph(), null, math);

        return false;
    }

    @Override
    public String[] supportedTags() {
        return TAGS;
    }

    @Override
    public boolean renderAsBlock() {
        return false;
    }

}

==> poi-tl-ext-0.4.13-poi5-sources.jar: org/ddr/poi/html/tag/MathRenderer.java <==
/*
 * Copyright 2016 - 2021 Draco, https://github.com/draco1023
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *     http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package org.ddr.poi.html.tag;

import org.ddr.poi.html.ElementRenderer;
import org.ddr.poi.html.HtmlConstants;
import org.ddr.poi.html.HtmlRenderContext;
import org.ddr.poi.math.MathMLUtils;
import org.jsoup.nodes.Document.OutputSettings;
import org.jsoup.nodes.Document.OutputSettings.Syntax;
import org.jsoup.nodes.Element;

import java.util.regex.Matcher;
import java.util.regex.Pattern;

/**
 * math标签渲染器
 *
 * @author Draco
 * @since 2021-02-18
 */
public class MathRenderer implements ElementRenderer {
    private static final String[] TAGS = {HtmlConstants.TAG_MATH};

    /**
     * 开始渲染
     *
     * @param element HTML元素
     * @param context 渲染上下文
     * @return 是否继续渲染子元素
     */
    @Override
    public boolean renderStart(Element element, HtmlRenderContext context) {
        OutputSettings outputSettings = element.ownerDocument().outputSettings();
        outputSettings.syntax(Syntax.xml);
        String math = element.outerHtml();
        outputSettings.syntax(Syntax.html);
        math = MathMLUtils.normalize(math);
        MathMLUtils.renderTo(context.getClosestParagraph(), context.newRun(), math);

        return false;
    }

    @Override
    public String[] supportedTags() {
        return TAGS;
    }

    @Override
    public boolean renderAsBlock() {
        return false;
    }

}
